#!/bin/bash

#####################
# This is Mac-only code for converting sketchup to zip. 
# You'll need to install Sketchup, and this script 
#    will use Ruby scripting within SketchUp to convert
#
#
# NOTE: enable AppleScript first: 
#     defaults write /Applications/Google\ SketchUp\ 8/SketchUp.app/Contents/Info NSAppleScriptEnabled -bool YES
#
# THEN: install appscript (not sure if needed?)
#	  sudo gem install rb-appscript
#
#
# Some things:
#     http://stackoverflow.com/questions/4982301/using-ruby-to-close-windows-on-mac-os-x
#	  https://developers.google.com/sketchup/docs/ourdoc/sketchup
#	  http://stackoverflow.com/questions/4982281/google-sketchup-close-file
#
#####################

if [ $# -lt 3 ]; then
	echo "Usage: "
	echo "	./$0 inDir outDir maxWindows"
	echo ""
	exit
fi

sketchup="/Applications/Google SketchUp 8/SketchUp.app/Contents/MacOS/SketchUp"
#sketchup="/Applications/Google SketchUp 8/SketchUp.app/"

inDir=$1
outDir=$2
maxWnd=$3

rm $inDir/RubyBatch*

let globCnt=0
let locCnt=0

if [ ! -d $outDir ]; then 
	mkdir $outDir
fi

rubyFile=$inDir/RubyBatch$globCnt.rb
echo "" > $rubyFile

script_dir=$(dirname $0)

myPath=`pwd`
lastExport="none" 
for file in `ls -1 $inDir/*.skp`
do
	if [ $locCnt -gt $maxWnd ]; then
		echo $myPath/$rubyFile
		"$sketchup" -RubyStartup $myPath/$rubyFile 1> $rubyFile.log 2> $rubyFile.err & 
		pid=$!
		sleep 5s
		osascript -e 'tell application "SketchUp" to activate'
		sleep $maxWnd"s"
		let sleptFor=0
		let sleptOverall=0
		while [ ! -f $lastExport ]; do
			sleep 5s
			let sleptFor=$sleptFor+5
			let sleptOverall=$sleptOverall+5
			echo "Waiting for "`basename $lastExport`" "$sleptOverall"s"
			# if not done after 5 minutes - kill
			if [ $sleptOverall -gt 600 ]; then
				kill $pid
				break
			fi
			# if not done after 15s, try to close the front window
			if [ $sleptFor -gt 30 ]; then
				osascript $script_dir/closeFront.applescript
				let sleptFor=0
				echo "    Trying to close"
			fi
		done
		for (( c=0; c<=$maxWnd; c++ )); do
			osascript -e 'tell application "SketchUp" to close window 2'
		done
		osascript -e 'tell application "SketchUp" to quit'
		
		let locCnt=0
		let globCnt=globCnt+1
		rubyFile=$inDir/RubyBatch$globCnt.rb
		echo "#!/usr/bin/ruby" > $rubyFile
	fi

	nopath=`basename $file`
	extOnly="."`echo "$nopath" | cut -d'.' -f2`
	fileOnly=`echo "$nopath" | cut -d'.' -f1`

	inFile="$myPath/$file"
	outFile="$myPath/$outDir/$fileOnly.kmz"

	if [ ! -f $outFile ]; then
		let locCnt=locCnt+1
		echo $globCnt $locCnt $file
		echo "Sketchup.open_file '$inFile'" >> $rubyFile
		echo "model = Sketchup.active_model" >> $rubyFile
		echo "model.export '$outFile'" >> $rubyFile
		lastExport="$outFile"
	fi
done

echo $myPath/$rubyFile
"$sketchup" -RubyStartup $myPath/$rubyFile 1> $rubyFile.log 2> $rubyFile.err & 
sleep 8s
osascript -e 'tell application "SketchUp" to activate'
while [ ! -f $lastExport ] && [ "$lastExport" != "none" ]; do
	sleep 5s
	echo "Waiting For "$lastExport
done
for (( c=0; c<=$maxWnd; c++ )); do
	osascript -e 'tell application "SketchUp" to close window 2'
done
osascript -e 'tell application "SketchUp" to quit'



